package com.dzeio.openhealth.adapters

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.annotation.DrawableRes
import com.dzeio.openhealth.core.BaseAdapter
import com.dzeio.openhealth.core.BaseViewHolder
import com.dzeio.openhealth.databinding.ItemListBinding
import com.dzeio.openhealth.utils.NetworkUtils

class ItemAdapter<T> : BaseAdapter<ItemAdapter.Item<T>, ItemListBinding>() {

    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> ItemListBinding
        get() = ItemListBinding::inflate

    var onItemClick: ((weight: Item<T>) -> Unit)? = null

    override fun onBindData(
        holder: BaseViewHolder<ItemListBinding>,
        item: Item<T>,
        position: Int
    ) {
        val binding = holder.binding

        binding.title.text = item.title
        binding.subValue.text = item.subtitle

        if (item.image != null) {
            NetworkUtils.getImageInBackground(binding.image, item.image)
        } else {
            binding.image.visibility = View.GONE
        }

        if (item.icon != null) {
            binding.iconRight.setImageResource(item.icon)
        } else {
            binding.iconRight.visibility = View.GONE
        }

        // set the callback
        binding.card.setOnClickListener {
            onItemClick?.invoke(item)
        }
    }

    data class Item<T>(
        val value: T,
        val title: String? = null,
        val subtitle: String? = null,
        val image: String? = null,
        @DrawableRes
        val icon: Int? = null
    )
}
