package com.dzeio.openhealth.core

import android.os.Bundle
import android.view.LayoutInflater
import androidx.appcompat.app.AppCompatActivity
import androidx.viewbinding.ViewBinding

/**
 * Base around the Activity class to simplify usage
 */
abstract class BaseActivity<VB : ViewBinding>() : AppCompatActivity() {

    /**
     * Function to inflate the Fragment Bindings
     *
     * use like this: `ViewBinding::inflater`
     */
    abstract val bindingInflater: (LayoutInflater) -> VB

    protected lateinit var binding: VB

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = bindingInflater(layoutInflater)

        setContentView(binding.root)

        onCreated(savedInstanceState)
    }

    protected open fun onCreated(savedInstanceState: Bundle?) {}
}
