package com.dzeio.openhealth.core

import android.app.Dialog
import android.os.Bundle
import android.view.LayoutInflater
import android.view.Menu
import android.view.MenuInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.DialogFragment
import androidx.lifecycle.ViewModelProvider
import androidx.viewbinding.ViewBinding
import com.dzeio.openhealth.R
import com.google.android.material.dialog.MaterialAlertDialogBuilder

/**
 * Base around the DialogFragment class to simplify usage
 */
abstract class BaseFullscreenDialog<VM : BaseViewModel, VB : ViewBinding>(
    private val viewModelClass: Class<VM>
) : DialogFragment() {

    /**
     * Lazyload the viewModel
     */
    val viewModel by lazy {
        ViewModelProvider(this)[viewModelClass]
    }

    private var _binding: VB? = null
    val binding get() = _binding!!

    /**
     * Function to inflate the Fragment Bindings
     */
    abstract val bindingInflater: (LayoutInflater) -> VB

    /**
     * Function run when the dialog was created
     */
    open fun onCreated(savedInstanceState: Bundle?) {}

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        _binding = bindingInflater(inflater)

        setHasOptionsMenu(true)

        onCreated(savedInstanceState)

        return binding.root
    }

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        return activity?.let { act ->
            val builder = MaterialAlertDialogBuilder(requireContext())

            _binding = bindingInflater(act.layoutInflater)

            builder.setView(binding.root)

            val dialog = builder.create()

            onDialogInit(dialog)

            dialog
        } ?: throw IllegalStateException("Activity cannot be null")
    }

    /**
     * Function to modify the Dialog
     */
    open fun onDialogInit(dialog: Dialog) {}

    /**
     * FIXME: Remove it from the Base and put it in the implementations
     */
    override fun onCreateOptionsMenu(menu: Menu, inflater: MenuInflater) {
        super.onCreateOptionsMenu(menu, inflater)

        menu.clear()
        requireActivity().menuInflater.inflate(R.menu.fullscreen_dialog, menu)
        super.onCreateOptionsMenu(menu, inflater)
    }

    /**
     * Destroy binding
     */
    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}
