package com.dzeio.openhealth.data.step

import java.util.Calendar
import java.util.TimeZone
import javax.inject.Inject
import javax.inject.Singleton
import kotlinx.coroutines.flow.filter
import kotlinx.coroutines.flow.firstOrNull

@Singleton
class StepRepository @Inject constructor(
    private val stepDao: StepDao
) {
    fun getSteps() = stepDao.getAll()

    fun lastStep() = stepDao.last()

    fun getStep(id: Long) = stepDao.getOne(id)

    suspend fun addStep(value: Step) = stepDao.insert(value)
    suspend fun updateStep(value: Step) = stepDao.update(value)

    suspend fun deleteStep(value: Step) = stepDao.delete(value)
    suspend fun deleteFromSource(value: String) = stepDao.deleteFromSource(value)

    suspend fun todaySteps(): Int {
        val cal = Calendar.getInstance(TimeZone.getTimeZone("UTC"))

        cal.set(Calendar.HOUR, 0)
        cal.set(Calendar.MINUTE, 0)
        cal.set(Calendar.SECOND, 0)
        cal.set(Calendar.MILLISECOND, 0)
        val steps = stepDao.getAfter(cal.timeInMillis).firstOrNull()
        if (steps == null) {
            return 0
        }

        var total = 0
        for (item in steps) {
            total += item.value
        }

        return total
    }

    fun currentStep() = lastStep().filter {
        return@filter it != null && it.isCurrent()
    }
}
