package com.dzeio.openhealth.ui.about

import android.annotation.SuppressLint
import android.content.ActivityNotFoundException
import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import com.dzeio.openhealth.BuildConfig
import com.dzeio.openhealth.R
import com.dzeio.openhealth.core.BaseStaticFragment
import com.dzeio.openhealth.databinding.FragmentAboutBinding
import com.google.android.gms.oss.licenses.OssLicensesMenuActivity

/**
 * Fragment for the About page
 */
class AboutFragment : BaseStaticFragment<FragmentAboutBinding>() {
    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> FragmentAboutBinding
        get() = FragmentAboutBinding::inflate

    @SuppressLint("StringFormatInvalid")
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        // set the version number
        binding.version.text =
            resources.getString(R.string.version_number, BuildConfig.VERSION_NAME)

        // handle contact US button
        binding.contactUs.setOnClickListener {
            openLink("mailto:contact.openhealth@dze.io")
        }

        // handle Github button
        binding.github.setOnClickListener {
            openLink("https://github.com/dzeiocom/OpenHealth")
        }

        // send the user to the Google OSS licenses page when clicked
        binding.licenses.setOnClickListener {
            startActivity(Intent(requireContext(), OssLicensesMenuActivity::class.java))
        }
    }

    /**
     * simple function that try to open a link.
     */
    private fun openLink(url: String) {
        try {
            val intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
            startActivity(intent)
        } catch (e: ActivityNotFoundException) {
            Toast.makeText(requireContext(), "Could not handle link $url", Toast.LENGTH_LONG).show()
        }
    }
}
