package com.dzeio.openhealth.ui.food

import android.view.LayoutInflater
import android.view.View
import androidx.appcompat.app.AlertDialog
import androidx.lifecycle.lifecycleScope
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import com.dzeio.openhealth.R
import com.dzeio.openhealth.adapters.ItemAdapter
import com.dzeio.openhealth.core.BaseDialog
import com.dzeio.openhealth.data.food.Food
import com.dzeio.openhealth.databinding.DialogSearchBinding
import com.dzeio.openhealth.utils.NetworkResult
import com.google.android.material.dialog.MaterialAlertDialogBuilder
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.coroutines.launch
import kotlin.math.roundToInt

@AndroidEntryPoint
class SearchFoodDialog :
    BaseDialog<SearchFoodDialogViewModel, DialogSearchBinding>(
        SearchFoodDialogViewModel::class.java
    ) {

    override val bindingInflater: (LayoutInflater) -> DialogSearchBinding =
        DialogSearchBinding::inflate

    override fun onBuilderInit(builder: MaterialAlertDialogBuilder) {
        super.onBuilderInit(builder)

        builder.apply {
            setTitle("Add Product")
            setIcon(R.drawable.ic_outline_fastfood_24)
            setNegativeButton(R.string.close) { dialog, _ ->
                dialog.cancel()
            }
            setNeutralButton("Search", null)
        }
    }

    override fun onDialogInit(dialog: AlertDialog) {
        super.onDialogInit(dialog)

        dialog.setOnShowListener {
            val btn = dialog.getButton(AlertDialog.BUTTON_NEUTRAL)
            btn.setOnClickListener {
                viewModel.search(binding.search.text.toString())
                binding.loading.visibility = View.VISIBLE
            }
        }
    }

    override fun onCreated() {
        super.onCreated()

        val recycler = binding.list

        val manager = LinearLayoutManager(requireContext())
        recycler.layoutManager = manager

        val adapter = ItemAdapter<Food>()
        adapter.onItemClick = {
            lifecycleScope.launch {
                val id = viewModel.addProduct(it.value)
                findNavController().navigate(
                    SearchFoodDialogDirections.actionNavDialogFoodSearchToNavDialogFoodProduct(
                        id,
                        true
                    )
                )
            }
        }
        recycler.adapter = adapter

        viewModel.items.observe(this) {
            if (it.data != null) {
                adapter.set(
                    it.data!!.map { food ->
                        ItemAdapter.Item(
                            food,
                            food.name,
                            getString(
                                R.string.food_description,
                                food.quantity.roundToInt().toString() + food.serving.replace(
                                    Regex("\\d+"),
                                    ""
                                ),
                                (food.energy / 100 * food.quantity)
                            ),
                            food.image
                        )
                    }
                )
            }
            if (it.status == NetworkResult.NetworkStatus.FINISHED) {
                binding.loading.visibility = View.GONE
            } else if (it.status == NetworkResult.NetworkStatus.ERRORED) {
                binding.errorText.visibility = View.VISIBLE
                binding.loading.visibility = View.GONE
            }
        }
    }
}
