package com.dzeio.openhealth.ui.food

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.food.Food
import com.dzeio.openhealth.data.food.FoodRepository
import com.dzeio.openhealth.utils.NetworkResult
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch

@HiltViewModel
class SearchFoodDialogViewModel @Inject internal constructor(
    private val foodRepository: FoodRepository
) : BaseViewModel() {
    val items: MutableLiveData<NetworkResult<List<Food>>> = MutableLiveData()

    fun search(text: String) {
        viewModelScope.launch {
            foodRepository.searchFood(text).collectLatest {
                items.postValue(it)
            }
        }
    }

    suspend fun addProduct(product: Food): Long {
        if (product.id > 0) {
            product.id = 0
        }
        return foodRepository.add(product)
    }
}
