package com.dzeio.openhealth.ui.water

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import com.dzeio.charts.Entry
import com.dzeio.charts.series.BarSerie
import com.dzeio.openhealth.R
import com.dzeio.openhealth.adapters.ItemAdapter
import com.dzeio.openhealth.core.BaseFragment
import com.dzeio.openhealth.data.water.Water
import com.dzeio.openhealth.databinding.FragmentMainWaterHomeBinding
import com.dzeio.openhealth.utils.ChartUtils
import dagger.hilt.android.AndroidEntryPoint
import java.text.SimpleDateFormat
import java.util.Date
import java.util.Locale

@AndroidEntryPoint
class WaterHomeFragment :
    BaseFragment<WaterHomeViewModel, FragmentMainWaterHomeBinding>(WaterHomeViewModel::class.java) {

    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> FragmentMainWaterHomeBinding =
        FragmentMainWaterHomeBinding::inflate

    private val adapter = ItemAdapter<Water>()

    private val serie by lazy { BarSerie(binding.chart) }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val recycler = binding.list

        recycler.layoutManager = LinearLayoutManager(requireContext())

        adapter.apply {
            onItemClick = {
                findNavController().navigate(
                    WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterEdit(
                        it.value.id
                    )
                )
            }
            recycler.adapter = this
        }

        binding.chart.apply {
            serie
            ChartUtils.materielTheme(this, requireView())

            yAxis.apply {
                setYMin(0f)
            }

            xAxis.apply {
                dataWidth = 604800000.0
                scrollEnabled = true
                onValueFormat = onValueFormat@{
                    return@onValueFormat SimpleDateFormat(
                        "yyyy-MM-dd",
                        Locale.getDefault()
                    ).format(Date(it.toLong()))
                }
            }
        }

        binding.buttonEditDefaultIntake.setOnClickListener {
            findNavController().navigate(
                WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterSizeDialog()
            )
        }

        viewModel.items.observe(viewLifecycleOwner) { list ->
            updateData()
        }
    }

    private fun updateData() {
        val data = viewModel.items.value
        val unit = viewModel.unit.value

        if (unit == null) {
            return
        }

        if (data.isNullOrEmpty()) {
            adapter.clear()
            serie.entries = arrayListOf()
            binding.chart.refresh()
            return
        }

        // Update adapter
        adapter.set(
            data.map {
                ItemAdapter.Item(
                    it,
                    getString(
                        unit.unit,
                        unit.fromMilliliter(it.value)
                    ),
                    it.formatTimestamp(),
                    icon = R.drawable.ic_outline_edit_24
                )
            }
        )

        // update graph
        val dataset = data.map {
            return@map Entry(
                it.timestamp.toDouble(),
                unit.fromMilliliter(it.value).toFloat()
            )
        }

        serie.entries = dataset as ArrayList<Entry>
        binding.chart.xAxis.x = 0.0
        binding.chart.refresh()
    }
}
