package com.dzeio.openhealth.ui.water

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.Settings
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.water.Water
import com.dzeio.openhealth.data.water.WaterRepository
import com.dzeio.openhealth.units.Volume
import com.dzeio.openhealth.utils.Configuration
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch

@HiltViewModel
class WaterHomeViewModel@Inject internal constructor(
    private val waterRepository: WaterRepository,
    config: Configuration
) : BaseViewModel() {
    val items: MutableLiveData<List<Water>> = MutableLiveData()

    private val _unit = MutableLiveData<Volume?>()
    val unit: LiveData<Volume?> = _unit
    init {
        viewModelScope.launch {
            waterRepository.getWaters().collectLatest {
                items.postValue(it)
            }
        }
        config.getInt((Settings.VOLUME_UNIT)).apply {
            addObserver {
                if (it === null) return@addObserver
                _unit.postValue(Volume.find(it))
            }
            if (value != null) _unit.postValue(Volume.find(value!!))
        }
    }
}
