package com.dzeio.openhealth.ui.weight

import android.annotation.SuppressLint
import androidx.annotation.RequiresPermission
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.weight.Weight
import com.dzeio.openhealth.data.weight.WeightRepository
import com.dzeio.openhealth.devices.BluetoothLeGattDevice
import com.dzeio.openhealth.utils.Bluetooth
import com.dzeio.openhealth.utils.Configuration
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject
import kotlinx.coroutines.flow.first

@HiltViewModel
class ScanScalesViewModel @Inject internal constructor(
    private val bluetooth: Bluetooth,
    private val weightRepository: WeightRepository,
    config: Configuration
) : BaseViewModel() {

    @SuppressLint("MissingPermission")
    @RequiresPermission(value = "android.permission.BLUETOOTH_SCAN")
    val devices = BluetoothLeGattDevice.findDevices(bluetooth, config).toLiveData()

    @RequiresPermission(value = "android.permission.BLUETOOTH_SCAN")
    fun stopScan() {
        bluetooth.stopScan()
    }

    suspend fun addWeights(weights: ArrayList<Weight>) {
        val current = weightRepository.getWeights().first()
        val toAdd = arrayListOf<Weight>()
        for (weight in weights) {
            if (current.find { it.equals(current) } != null) {
                continue
            }
            toAdd.add(weight)
        }
        weightRepository.addAll(*toAdd.toTypedArray())
    }
}
