package com.dzeio.openhealth.units

import com.dzeio.openhealth.R

enum class Mass(
    /**
     * Value based on the Kilogram
     */
    val modifier: Float,
    val singular: Int,
    val plural: Int,
    val unit: Int
) {
    KILOGRAM(
        1f,
        R.string.unit_mass_kilogram_name_singular,
        R.string.unit_mass_kilogram_name_plural,
        R.string.unit_mass_kilogram_unit
    ),
    POUND(
        2.204623f,
        R.string.unit_mass_pound_name_singular,
        R.string.unit_mass_pound_name_plural,
        R.string.unit_mass_pound_unit
    );

    companion object {
        fun find(index: Int): Mass {
            return Mass.values().getOrNull(index) ?: KILOGRAM
        }
    }

    fun format(value: Float): Float {
        return value * modifier
    }

    /**
     * transform the value from the specified unit to kilograms
     */
    fun toKilogram(value: Float): Float = value / modifier
    fun toKilogram(value: Int): Int = toKilogram(value.toFloat()).toInt()

    /**
     * transform the value from the specified unit to kilograms
     */
    fun fromKilogram(value: Float): Float = value * modifier
    fun fromKilogram(value: Int): Int = fromKilogram(value.toFloat()).toInt()
}
