package com.dzeio.openhealth.utils

import android.view.View
import com.dzeio.charts.ChartView
import com.dzeio.charts.components.Annotation
import com.dzeio.charts.series.BarSerie
import com.dzeio.charts.series.LineSerie
import com.google.android.material.color.MaterialColors
import java.text.DateFormat
import java.util.Date
import java.util.Locale
import kotlin.math.roundToLong

/**
 * Utils object to create Charts
 */
object ChartUtils {

    /**
     * Apply Material theme to a DzeioChart [ChartView]
     */
    fun materielTheme(chart: ChartView, view: View) {
        chart.apply {
            annotator.apply {
                backgroundPaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorBackgroundFloating
                )
                titlePaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorOnBackground
                )
                subTitlePaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorOnBackground
                )

                orientation = Annotation.Orientation.VERTICAL

                annotationTitleFormat = { it.y.roundToLong().toString() }
                annotationSubTitleFormat = annotationSubTitleFormat@{
                    val formatter = DateFormat.getDateTimeInstance(
                        DateFormat.SHORT,
                        DateFormat.SHORT,
                        Locale.getDefault()
                    )
                    return@annotationSubTitleFormat formatter.format(Date(it.x.roundToLong()))
                }
            }
            yAxis.apply {
                textLabel.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
                linePaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
                goalLinePaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorError
                )
            }

            xAxis.apply {
                textPaint.color = MaterialColors.getColor(
                    view,
                    com.google.android.material.R.attr.colorOnPrimaryContainer
                )
            }

            for (serie in series) {
                if (serie is BarSerie) {
                    serie.apply {
                        barPaint.color = MaterialColors.getColor(
                            view,
                            com.google.android.material.R.attr.colorPrimary
                        )
                        textPaint.color = MaterialColors.getColor(
                            view,
                            com.google.android.material.R.attr.colorOnPrimary
                        )
                    }
                } else if (serie is LineSerie) {
                    serie.apply {
                        linePaint.color = MaterialColors.getColor(
                            view,
                            com.google.android.material.R.attr.colorPrimary
                        )
                        textPaint.color = MaterialColors.getColor(
                            view,
                            com.google.android.material.R.attr.colorOnPrimary
                        )
                    }
                }
            }
        }
    }
}
